==> 0.0.1.tar.gz: lib/core/data/service/repository/account_repository_impl.dart <==
import 'package:fcm_config/fcm_config.dart';
import 'package:injectable/injectable.dart';
import 'package:sharing/remote/base_service.dart';
import 'package:sharing/remote/network/either.dart';
import 'package:sharing/remote/network/fetch_data.dart';
import 'package:sharing/remote/network/fetch_failure.dart';
import '../../models/fcm_model/fcm_model.dart';
import '../account_repository.dart';
import '../account_service.dart';
import '../firebase_service.dart';

import '../../local/shared_pref_source.dart';
import '../../params/device_params.dart';

@Injectable(as: AccountRepository)
class AccountRepositoryImpl extends BaseService with AccountRepository {
  final AccountService accountService;
  final FirebaseService firebaseService;
  final SharePrefSource localDataSource;

  AccountRepositoryImpl(
      this.accountService, this.firebaseService, this.localDataSource);

@override
  Future<Either<FetchFailure, FcmModel?>> sendCallNotification(
      {required String? id,
      required String? authen,
      required String? name,
      required String? phone,
      final String? email,
      final String? roomName,
      final String? roomId,
      List<String>? usersId,
      required List<String> usersToNotify}) async {
    final params = <String, dynamic>{
      'priority': 'high',
      'data': <String, dynamic>{
        "id": id,
        "phone": phone,
        "name": name,
        "email": email,
        "showWhen": true,
        "autoCancel": true,
        "privacy": "Private",
        "usersId": usersId,
        "roomId": roomId
      },
      'registration_ids': usersToNotify,
    };
    final callApi = firebaseService.sendCallNotification(authen!, params);
    return await safeFetch(() => callApi);
  }

  @override
  Future<void> signIn(
      {required String loginkey,
      required password,
      required deviceId,
      required Function(FetchData) funDataServer,
      required Function(FetchFailure) funError}) async {
    final deviceToken = await FirebaseMessaging.instance.getToken() ?? "000000";
    final callApi = accountService.signIn(
      deviceId: deviceToken,
      loginKey: loginkey,
      password: password,
    );
    await safeCallObjectStatus(
        response: await safeFetchV2(() => callApi),
        funDataServer: funDataServer,
        funError: funError);
  }

  @override
  Future<Either<FetchFailure, String?>> signOut() async {
    final callApi = accountService.signOut();
    return await safeCallMessageStatus(
        response: await safeFetchV2(() => callApi));
  }

  @override
  Future<void> call(
      {required String receiverId,
      required Function(FetchData) funDataServer,
      required Function(FetchFailure) funError}) async {
    final callApi = accountService.call(receiverId: receiverId);
    await safeCallObjectStatus(
        response: await safeFetchV2(() => callApi),
        funDataServer: funDataServer,
        funError: funError);
  }

  @override
  Future<void> getExpertList(
      {required Function(FetchData) funDataServer,
      required Function(FetchFailure) funError}) async {
    final callApi = accountService.getExpertList();
    await safeCallListStatus(
        response: await safeFetchV2(() => callApi),
        funDataServer: funDataServer,
        funError: funError);
  }

  @override
  Future<void> devices(
      {required DeviceParams params,
      required Function(FetchData) funDataServer,
      required Function(FetchFailure) funError}) async {
    final callApi = accountService.devices(
        deviceId: params.deviceId,
        deviceName: params.deviceName,
        deviceType: params.deviceType,
        deviceToken: params.deviceToken,
        appVersion: params.appVersion,
        osVersion: params.osVersion);
    await safeCallObjectStatus(
        response: await safeFetchV2(() => callApi),
        funDataServer: funDataServer,
        funError: funError);
  }
}

==> 0.0.2+4.tar.gz: lib/core/data/service/repository/account_repository_impl.dart <==
import 'package:injectable/injectable.dart';
import 'package:sharing/remote/network/either.dart';
import 'package:sharing/remote/network/fetch_data.dart';
import 'package:sharing/remote/network/fetch_failure.dart';
import 'package:sharing/remote/base_service.dart';

import '../../../../shared/helper/utils_helper.dart';
import '../../params/device_params.dart';
import '../account_repository.dart';
import '../account_service.dart';

@Injectable(as: AccountRepository)
class AccountRepositoryImpl extends BaseService with AccountRepository {
  final AccountService accountService;

  AccountRepositoryImpl(this.accountService);

  @override
  Future<void> signIn(
      {required String loginkey,
      required password,
      required deviceId,
      required Function(FetchData) funDataServer,
      required Function(FetchFailure) funError}) async {
    var deviceId = await Util.getDeviceId();
    final callApi = accountService.signIn(
      deviceId: deviceId,
      loginKey: loginkey,
      password: password,
    );
    await safeCallObjectStatus(
        response: await safeFetchV2(() => callApi),
        funDataServer: funDataServer,
        funError: funError);
  }

  @override
  Future<Either<FetchFailure, String?>> signOut() async {
    final callApi = accountService.signOut();
    return await safeCallMessageStatus(
        response: await safeFetchV2(() => callApi));
  }

  @override
  Future<void> getExpertList(
      {String? specialize,
      required Function(FetchData) funDataServer,
      required Function(FetchFailure) funError}) async {
    final callApi = accountService.getExpertList(specialize: specialize);
    await safeCallListStatus(
        response: await safeFetchV2(() => callApi),
        funDataServer: funDataServer,
        funError: funError);
  }

  @override
  Future<void> getSpecializesList(
      {required Function(FetchData) funDataServer,
      required Function(FetchFailure) funError}) async {
    final callApi = accountService.getSpecializesList();
    await safeCallListStatus(
        response: await safeFetchV2(() => callApi),
        funDataServer: funDataServer,
        funError: funError);
  }

  @override
  Future<void> getUser(
      {required Function(FetchData) funDataServer,
      required Function(FetchFailure) funError}) async {
    final callApi = accountService.getUser();
    await safeCallObjectStatus(
        response: await safeFetchV2(() => callApi),
        funDataServer: funDataServer,
        funError: funError);
  }

  @override
  Future<void> devices(
      {required DeviceParams params,
      required Function(FetchData) funDataServer,
      required Function(FetchFailure) funError}) async {
    final callApi = accountService.devices(
        deviceId: params.deviceId,
        deviceName: params.deviceName,
        deviceType: params.deviceType,
        deviceToken: params.deviceToken,
        appVersion: params.appVersion,
        osVersion: params.osVersion);
    await safeCallObjectStatus(
        response: await safeFetchV2(() => callApi),
        funDataServer: funDataServer,
        funError: funError);
  }
}
